"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = require("events");
class Queue extends events_1.EventEmitter {
    constructor(store, guildID) {
        super();
        this.store = store;
        this.guildID = guildID;
        this.keys = {
            list: `playlists.${this.guildID}`,
            np: `playlists.${this.guildID}.np`,
        };
        this.on('event', async (d) => {
            try {
                // if the track wasn't replaced, continue playing the next song
                if (d.reason !== 'REPLACED') {
                    await this._redis.del(this.keys.np);
                    await this.start();
                }
            }
            catch (e) {
                this.store.client.emit('error', e);
            }
        });
        this.on('playerUpdate', async (d) => {
            try {
                await this._redis.hset(this.keys.np, 'position', d.state.position);
            }
            catch (e) {
                this.store.client.emit('error', e);
            }
        });
    }
    get player() {
        return this.store.client.players.get(this.guildID);
    }
    async start() {
        const np = await this.current();
        if (np) {
            await this.player.play(np.track, { start: Number(np.position) || 0 });
            return true;
        }
        else {
            const next = await this._redis.lpop(this.keys.list);
            if (!next) {
                await this._redis.del(this.keys.list, this.keys.np);
                return false;
            }
            await this.player.play(next);
            await this._redis.hset(this.keys.np, 'track', next);
            return true;
        }
    }
    add(...tracks) {
        if (!tracks.length)
            return Promise.resolve(0);
        return this._redis.rpush(this.keys.list, ...tracks);
    }
    remove(track) {
        return this._redis.lrem(this.keys.list, 1, track);
    }
    async next() {
        await this._redis.del(this.keys.np);
        return this.start();
    }
    async stop() {
        await this.clear();
        await this.player.stop();
    }
    clear() {
        return this._redis.del(this.keys.list);
    }
    async current() {
        const cur = await this._redis.hgetall(this.keys.np);
        return Object.keys(cur).length ? cur : null;
    }
    tracks() {
        return this._redis.lrange(this.keys.list, 0, -1);
    }
    get _redis() {
        return this.store.redis;
    }
}
exports.default = Queue;

//# sourceMappingURL=Queue.js.map
