"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Queue_1 = require("./Queue");
class QueueStore extends Map {
    constructor(client, redis) {
        super();
        this.client = client;
        this.redis = redis;
    }
    get(key) {
        let queue = super.get(key);
        if (!queue) {
            queue = new Queue_1.default(this, key);
            this.set(key, queue);
        }
        return queue;
    }
    async start() {
        const keys = await this._scan('playlists.*');
        const guilds = keys.map(key => {
            const match = key.match(/^playlists\.(\d+)/);
            if (match)
                return match[1];
            throw new Error('error extracting guild ID from playlist');
        });
        for (const guild of guilds)
            this.get(guild).start();
    }
    async _scan(pattern, cursor = 0, keys = []) {
        const response = await this.redis.scan(cursor, 'MATCH', pattern);
        keys.push(...response[1]);
        if (response[0] === '0')
            return keys;
        return this._scan(pattern, response[0], keys);
    }
}
exports.default = QueueStore;

//# sourceMappingURL=QueueStore.js.map
